#include "CivInpDirector.h"
#include "CivInpBuilder.h"


void CivInpDirector::setBuilder(CivInpBuilder* builder)
{
	mBuilder = builder;
}

void CivInpDirector::create()
{
	if (mBuilder == NULL)
		return;

	mBuilder->preHandleLikelyPipe(); // 增加预处理阀门，水泵等类管网类型
	mBuilder->buildTank();
	mBuilder->buildReservoir();
	mBuilder->buildPatterns();
	mBuilder->buildNode();
	mBuilder->buildPipe();
	mBuilder->buildPump();
	mBuilder->buildVavle();
	mBuilder->buildEmitter();
	mBuilder->buildParamter();
	mBuilder->buildCoordnates();
	mBuilder->buildVertices();
	mBuilder->buildLabels();
	mBuilder->buildTags();
	mBuilder->buildBackDrop();
	mBuilder->buildQuality();
	mBuilder->buildSources();
	mBuilder->buildMixing();
	mBuilder->buildCurves();
	mBuilder->buildStatus();
	mBuilder->buildControls();
	mBuilder->buildRules();
	mBuilder->buildDemands();
}